
Structure Rule Group
--------------------

Rules Enforcing Structure Rule Group
####################################

* `after_001 <../after_rules.html#after-001>`_
* `after_003 <../after_rules.html#after-003>`_
* `alias_declaration_001 <../alias_rules.html#alias-declaration-001>`_
* `architecture_005 <../architecture_rules.html#architecture-005>`_
* `architecture_006 <../architecture_rules.html#architecture-006>`_
* `architecture_010 <../architecture_rules.html#architecture-010>`_
* `architecture_024 <../architecture_rules.html#architecture-024>`_
* `assert_002 <../assert_rules.html#assert-002>`_
* `assert_003 <../assert_rules.html#assert-003>`_
* `assert_004 <../assert_rules.html#assert-004>`_
* `assert_005 <../assert_rules.html#assert-005>`_
* `block_001 <../block_rules.html#block-001>`_
* `block_002 <../block_rules.html#block-002>`_
* `block_003 <../block_rules.html#block-003>`_
* `block_004 <../block_rules.html#block-004>`_
* `block_005 <../block_rules.html#block-005>`_
* `block_006 <../block_rules.html#block-006>`_
* `block_007 <../block_rules.html#block-007>`_
* `block_comment_001 <../block_comment_rules.html#block-comment-001>`_
* `block_comment_002 <../block_comment_rules.html#block-comment-002>`_
* `block_comment_003 <../block_comment_rules.html#block-comment-003>`_
* `case_012 <../case_rules.html#case-012>`_
* `case_019 <../case_rules.html#case-019>`_
* `case_020 <../case_rules.html#case-020>`_
* `comment_011 <../comment_rules.html#comment-011>`_
* `comment_012 <../comment_rules.html#comment-012>`_
* `component_005 <../component_rules.html#component-005>`_
* `component_019 <../component_rules.html#component-019>`_
* `component_021 <../component_rules.html#component-021>`_
* `component_022 <../component_rules.html#component-022>`_
* `concurrent_005 <../concurrent_rules.html#concurrent-005>`_
* `concurrent_011 <../concurrent_rules.html#concurrent-011>`_
* `concurrent_012 <../concurrent_rules.html#concurrent-012>`_
* `conditional_waveforms_001 <../conditional_waveforms_rules.html#conditional-waveforms-001>`_
* `constant_007 <../constant_rules.html#constant-007>`_
* `constant_016 <../constant_rules.html#constant-016>`_
* `constant_017 <../constant_rules.html#constant-017>`_
* `context_005 <../context_rules.html#context-005>`_
* `context_006 <../context_rules.html#context-006>`_
* `context_007 <../context_rules.html#context-007>`_
* `context_008 <../context_rules.html#context-008>`_
* `context_009 <../context_rules.html#context-009>`_
* `context_010 <../context_rules.html#context-010>`_
* `context_011 <../context_rules.html#context-011>`_
* `context_021 <../context_rules.html#context-021>`_
* `context_022 <../context_rules.html#context-022>`_
* `context_ref_005 <../context_ref_rules.html#context-ref-005>`_
* `entity_005 <../entity_rules.html#entity-005>`_
* `entity_015 <../entity_rules.html#entity-015>`_
* `entity_019 <../entity_rules.html#entity-019>`_
* `entity_021 <../entity_rules.html#entity-021>`_
* `entity_022 <../entity_rules.html#entity-022>`_
* `entity_023 <../entity_rules.html#entity-023>`_
* `entity_024 <../entity_rules.html#entity-024>`_
* `entity_025 <../entity_rules.html#entity-025>`_
* `entity_026 <../entity_rules.html#entity-026>`_
* `entity_027 <../entity_rules.html#entity-027>`_
* `entity_028 <../entity_rules.html#entity-028>`_
* `entity_029 <../entity_rules.html#entity-029>`_
* `function_018 <../function_rules.html#function-018>`_
* `function_019 <../function_rules.html#function-019>`_
* `function_020 <../function_rules.html#function-020>`_
* `generate_011 <../generate_rules.html#generate-011>`_
* `generate_019 <../generate_rules.html#generate-019>`_
* `generate_020 <../generate_rules.html#generate-020>`_
* `generate_021 <../generate_rules.html#generate-021>`_
* `generic_010 <../generic_rules.html#generic-010>`_
* `generic_013 <../generic_rules.html#generic-013>`_
* `generic_016 <../generic_rules.html#generic-016>`_
* `generic_018 <../generic_rules.html#generic-018>`_
* `generic_021 <../generic_rules.html#generic-021>`_
* `generic_map_003 <../generic_map_rules.html#generic-map-003>`_
* `generic_map_004 <../generic_map_rules.html#generic-map-004>`_
* `generic_map_005 <../generic_map_rules.html#generic-map-005>`_
* `generic_map_008 <../generic_map_rules.html#generic-map-008>`_
* `if_002 <../if_rules.html#if-002>`_
* `if_020 <../if_rules.html#if-020>`_
* `if_021 <../if_rules.html#if-021>`_
* `if_022 <../if_rules.html#if-022>`_
* `if_023 <../if_rules.html#if-023>`_
* `if_024 <../if_rules.html#if-024>`_
* `if_035 <../if_rules.html#if-035>`_
* `if_036 <../if_rules.html#if-036>`_
* `instantiation_005 <../instantiation_rules.html#instantiation-005>`_
* `instantiation_012 <../instantiation_rules.html#instantiation-012>`_
* `instantiation_033 <../instantiation_rules.html#instantiation-033>`_
* `instantiation_034 <../instantiation_rules.html#instantiation-034>`_
* `instantiation_035 <../instantiation_rules.html#instantiation-035>`_
* `library_010 <../library_rules.html#library-010>`_
* `library_011 <../library_rules.html#library-011>`_
* `loop_statement_001 <../loop_statement_rules.html#loop-statement-001>`_
* `loop_statement_002 <../loop_statement_rules.html#loop-statement-002>`_
* `loop_statement_003 <../loop_statement_rules.html#loop-statement-003>`_
* `loop_statement_004 <../loop_statement_rules.html#loop-statement-004>`_
* `loop_statement_005 <../loop_statement_rules.html#loop-statement-005>`_
* `loop_statement_006 <../loop_statement_rules.html#loop-statement-006>`_
* `loop_statement_007 <../loop_statement_rules.html#loop-statement-007>`_
* `package_005 <../package_rules.html#package-005>`_
* `package_007 <../package_rules.html#package-007>`_
* `package_014 <../package_rules.html#package-014>`_
* `package_body_001 <../package_body_rules.html#package-body-001>`_
* `package_body_002 <../package_body_rules.html#package-body-002>`_
* `package_body_003 <../package_body_rules.html#package-body-003>`_
* `port_012 <../port_rules.html#port-012>`_
* `port_013 <../port_rules.html#port-013>`_
* `port_014 <../port_rules.html#port-014>`_
* `port_016 <../port_rules.html#port-016>`_
* `port_021 <../port_rules.html#port-021>`_
* `port_023 <../port_rules.html#port-023>`_
* `port_026 <../port_rules.html#port-026>`_
* `port_027 <../port_rules.html#port-027>`_
* `port_map_003 <../port_map_rules.html#port-map-003>`_
* `port_map_004 <../port_map_rules.html#port-map-004>`_
* `port_map_005 <../port_map_rules.html#port-map-005>`_
* `port_map_008 <../port_map_rules.html#port-map-008>`_
* `port_map_009 <../port_map_rules.html#port-map-009>`_
* `port_map_010 <../port_map_rules.html#port-map-010>`_
* `procedure_012 <../procedure_rules.html#procedure-012>`_
* `procedure_013 <../procedure_rules.html#procedure-013>`_
* `procedure_014 <../procedure_rules.html#procedure-014>`_
* `procedure_call_001 <../procedure_call_rules.html#procedure-call-001>`_
* `procedure_call_002 <../procedure_call_rules.html#procedure-call-002>`_
* `procedure_call_003 <../procedure_call_rules.html#procedure-call-003>`_
* `process_010 <../process_rules.html#process-010>`_
* `process_012 <../process_rules.html#process-012>`_
* `process_016 <../process_rules.html#process-016>`_
* `process_018 <../process_rules.html#process-018>`_
* `process_029 <../process_rules.html#process-029>`_
* `process_030 <../process_rules.html#process-030>`_
* `process_037 <../process_rules.html#process-037>`_
* `process_038 <../process_rules.html#process-038>`_
* `process_039 <../process_rules.html#process-039>`_
* `record_type_definition_001 <../record_type_definition_rules.html#record-type-definition-001>`_
* `record_type_definition_002 <../record_type_definition_rules.html#record-type-definition-002>`_
* `record_type_definition_003 <../record_type_definition_rules.html#record-type-definition-003>`_
* `record_type_definition_004 <../record_type_definition_rules.html#record-type-definition-004>`_
* `record_type_definition_005 <../record_type_definition_rules.html#record-type-definition-005>`_
* `record_type_definition_006 <../record_type_definition_rules.html#record-type-definition-006>`_
* `record_type_definition_007 <../record_type_definition_rules.html#record-type-definition-007>`_
* `report_statement_001 <../report_statement_rules.html#report-statement-001>`_
* `report_statement_002 <../report_statement_rules.html#report-statement-002>`_
* `reserved_001 <../reserved_rules.html#reserved-001>`_
* `selected_assignment_001 <../selected_assignment_rules.html#selected-assignment-001>`_
* `selected_assignment_002 <../selected_assignment_rules.html#selected-assignment-002>`_
* `selected_assignment_003 <../selected_assignment_rules.html#selected-assignment-003>`_
* `selected_assignment_004 <../selected_assignment_rules.html#selected-assignment-004>`_
* `selected_assignment_005 <../selected_assignment_rules.html#selected-assignment-005>`_
* `selected_assignment_006 <../selected_assignment_rules.html#selected-assignment-006>`_
* `selected_assignment_007 <../selected_assignment_rules.html#selected-assignment-007>`_
* `selected_assignment_008 <../selected_assignment_rules.html#selected-assignment-008>`_
* `selected_assignment_009 <../selected_assignment_rules.html#selected-assignment-009>`_
* `selected_assignment_010 <../selected_assignment_rules.html#selected-assignment-010>`_
* `selected_assignment_011 <../selected_assignment_rules.html#selected-assignment-011>`_
* `selected_assignment_012 <../selected_assignment_rules.html#selected-assignment-012>`_
* `sequential_006 <../sequential_rules.html#sequential-006>`_
* `sequential_007 <../sequential_rules.html#sequential-007>`_
* `sequential_008 <../sequential_rules.html#sequential-008>`_
* `sequential_009 <../sequential_rules.html#sequential-009>`_
* `signal_007 <../signal_rules.html#signal-007>`_
* `signal_015 <../signal_rules.html#signal-015>`_
* `signal_017 <../signal_rules.html#signal-017>`_
* `source_file_001 <../source_file_rules.html#source-file-001>`_
* `type_008 <../type_rules.html#type-008>`_
* `type_009 <../type_rules.html#type-009>`_
* `type_017 <../type_rules.html#type-017>`_
* `type_018 <../type_rules.html#type-018>`_
* `variable_007 <../variable_rules.html#variable-007>`_
* `variable_017 <../variable_rules.html#variable-017>`_
* `variable_assignment_006 <../variable_assignment_rules.html#variable-assignment-006>`_
* `variable_assignment_007 <../variable_assignment_rules.html#variable-assignment-007>`_
* `variable_assignment_008 <../variable_assignment_rules.html#variable-assignment-008>`_
* `when_001 <../when_rules.html#when-001>`_
